@@ -1,5 +1,5 @@
 from calculation.distance import Distance
-
+from calculation.pixel import Pixel
 
 class Intersection:
 
@@ -59,6 +59,7 @@ class Intersection:
 
         denominator = ((line2EndY - line2StartY) * (line1EndX - line1StartX)) - (
                 (line2EndX - line2StartX) * (line1EndY - line1StartY))
+
         if (denominator == 0):
             return result
 
@@ -166,26 +167,50 @@ class Intersection:
         # return the intersection over union value
 
     def IntersectionPointsFind(self, start_lat1, start_lon1, theta1, start_lat2, start_lon2, theta2):
+
         ops1, ops2 = self.opsDetect([start_lat1, start_lon1, theta1,
                                      start_lat2, start_lon2, theta2],
                                     )
 
-        # intSection1Lat, intSection1Lon, intSection2Lat, intSection2Lon = interSections(ops1["lat"],    ops1["lon"],
-        #                                                                                  ops2["lat"],
-        #                                                                                  ops2["lon"])
+        intSection1Lat, intSection1Lon, \
+        intSection2Lat, intSection2Lon = self.intersection_decimal_to_float(ops1["lat"],
+                                                                            ops1["lon"],
+                                                                            ops2["lat"],
+                                                                            ops2["lon"])
 
         destinationPoint1 = [(start_lat1, start_lon1),
-                             (ops1["lat"], ops1["lon"])]
+                             (intSection1Lat, intSection1Lon)]
 
         destinationPoint2 = [(start_lat2, start_lon2),
-                             (ops2["lat"], ops2["lon"])]
+                             (intSection2Lat, intSection2Lon)]
 
         interSection = self.checkLineIntersection(start_lat1,
                                                   start_lon1,
-                                                  ops1["lat"], ops1["lon"],
+                                                  intSection1Lat, intSection1Lon,
 
                                                   start_lat2,
                                                   start_lon2,
-                                                  ops2["lat"], ops2["lon"])
+                                                  intSection2Lat, intSection2Lon)
 
         return interSection, destinationPoint1, destinationPoint2
+
+    @staticmethod
+    def intersection_decimal_to_float(lat1, lon1, lat2, lon2):
+        """
+
+        Parameters
+        ----------
+        lat1
+        lon1
+        lat2
+        lon2
+
+        Returns points convert decimal format
+        -------
+
+        """
+        lat1 = Pixel.decimalFix(lat1)
+        lon1 = Pixel.decimalFix(lon1)
+        lat2 = Pixel.decimalFix(lat2)
+        lon2 = Pixel.decimalFix(lon2)
+        return lat1, lon1, lat2, lon2
\ No newline at end of file
